/*
 * SAS Code to process data passed in from a DDC report object
 */

/*
 * create temp dir for json data
 * just to be on the save side
 */
options dlcreatedir;
libname ddcdata "%sysfunc(pathname(work))/ddc_data";

title "sysuserid=&sysuserid sysjobid=&sysjobid";


/*
 * print all macro vars if requested, might be useful
 */
%if %upcase(&printmvars) = TRUE %then %do;
proc sql;
	create table myvars as
	select 
		*
	from
		dictionary.macros
		/*
	where
		scope = "GLOBAL"
		*/
	order by
		scope
		, name
	;
quit;

proc print data=myvars;
run;
%end;

/*
 * read the data passed from VA
 */
  
filename upload filesrvc "&_WEBIN_FILEURI";
libname injson json fileref=upload noalldata;

proc datasets lib=ddcdata kill nolist;
run;
quit;

proc copy in=injson out=ddcdata;
run;

title2 "datasets from json input";
proc datasets lib=ddcdata;
run;
quit;

/*
 * print the different tables with data passed in
 */
%macro print_if_exist(dsn);
	%if %sysfunc(exist(&dsn)) %then %do;
		title2 "&dsn";
		proc print data=&dsn;
		run;
	%end;
	%else %do;
		%put WARNING: &sysmacroname &dsn does not exist;
	%end;
%mend;

%print_if_exist(ddcdata.root)
%print_if_exist(ddcdata.data)
%print_if_exist(ddcdata.columns)
%print_if_exist(ddcdata.columns_format)
%print_if_exist(ddcdata.parameters)
